#include <Engine/types/entity/Sprite.h>
#include <JGL/JGL.h>

Engine::Sprite::~Sprite() {
    delete texture;
    delete alpha_mask;
}

void Engine::Sprite::Render() {
    auto* t = GetTexture();
    auto* a = GetAlphaMask();

    if (t && !a)
        return J2D::DrawSprite(t, GetRenderPosition(), face_angle, origin, scale, base_color);
    if (t && a)
        return J2D::DrawSprite(t, a, GetRenderPosition(), face_angle, origin, scale, base_color);
}

Texture* Engine::Sprite::GetTexture() const {
    return texture;
}

Texture* Engine::Sprite::GetAlphaMask() const {
    return alpha_mask;
}

void Engine::Sprite::SetAlphaMask(Texture* new_alpha_mask) {
    alpha_mask = new_alpha_mask;
}

Vector2 Engine::Sprite::GetRenderPosition() const {
    return position - (origin * GetTexture()->GetDimensions());
}

void Engine::Sprite::SetOrigin(const Vector2& new_origin) {
    origin = new_origin;
}

Vector2 Engine::Sprite::GetLocalSpaceOrigin() const {
    return origin;
}
